#include <stdio.h>

void
gtk_drag_set_icon_gicon (void *context,
                         void *icon,
                         int hot_x,
                         int hot_y)
{
    printf("gtk_drag_set_icon_gicon not implemented");
}

void
gtk_drag_source_set_icon_gicon (void *widget,
                                void *icon)
{
    printf("gtk_drag_source_set_icon_gicon not implemented");
}

